@@ -33,12 +33,15 @@
 #include "tracker-debug.h"
 #include "tracker-domain-ontology.h"
 #include "tracker-enums.h"
+#include "tracker-error-report.h"
 #include "tracker-file-utils.h"
 #include "tracker-fts-config.h"
 #include "tracker-ioprio.h"
-#include "tracker-language.h"
+#include "tracker-miner-object.h"
+#include "tracker-miner-proxy.h"
 #include "tracker-sched.h"
 #include "tracker-seccomp.h"
+#include "tracker-term-utils.h"
 #include "tracker-type-utils.h"
 #include "tracker-utils.h"
 #include "tracker-locale.h"
