@@ -267,8 +267,6 @@ do_main (int argc, char *argv[])
 	TrackerDomainOntology *domain_ontology;
 	gchar *dbus_name, *miner_dbus_name;
 
-	g_setenv ("GST_REGISTRY_UPDATE", "no", TRUE);
-
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
@@ -329,9 +327,6 @@ do_main (int argc, char *argv[])
 
 	tracker_content_identifier_cache_init ();
 
-	tracker_extract_module_manager_init ();
-	tracker_module_manager_load_modules ();
-
 	/* Set conditions when we use stand alone settings */
 	if (filename) {
 		return run_standalone ();
@@ -343,6 +338,8 @@ do_main (int argc, char *argv[])
 		return EXIT_FAILURE;
 	}
 
+	tracker_module_manager_load_modules ();
+
 	miner_dbus_name = tracker_domain_ontology_get_domain (domain_ontology,
 	                                                      MINER_FS_NAME_SUFFIX);
 	sparql_connection = tracker_sparql_connection_bus_new (miner_dbus_name,
@@ -379,7 +376,13 @@ do_main (int argc, char *argv[])
 
 	tracker_locale_sanity_check ();
 
-	controller = tracker_extract_controller_new (decorator, connection, persistence);
+	controller = tracker_extract_controller_new (decorator, connection, persistence, &error);
+	if (error) {
+		g_critical ("Could not create extraction controller: %s", error->message);
+		g_error_free (error);
+		g_object_unref (decorator);
+		return EXIT_FAILURE;
+	}
 
 	/* Request DBus name */
 	dbus_name = tracker_domain_ontology_get_domain (domain_ontology, DBUS_NAME_SUFFIX);
